Skip to main content
summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorpfullbright2008-10-14 15:44:21 +0000
committerpfullbright2008-10-14 15:44:21 +0000
commit618e4b5b8231403eaae939c5dfb0e6a174a42974 (patch)
tree9479d910b0d59a612194ec4a99aa1b3de14e3dff /jpa/plugins/org.eclipse.jpt.core/src/org/eclipse/jpt/core/context/MappingFile.java
parentdb30d0733728a69bb94ba9f41d21242d7046fd38 (diff)
downloadwebtools.dali-618e4b5b8231403eaae939c5dfb0e6a174a42974.tar.gz
webtools.dali-618e4b5b8231403eaae939c5dfb0e6a174a42974.tar.xz
webtools.dali-618e4b5b8231403eaae939c5dfb0e6a174a42974.zip
removed orm references from core and persistence context code
Diffstat (limited to 'jpa/plugins/org.eclipse.jpt.core/src/org/eclipse/jpt/core/context/MappingFile.java')
-rw-r--r--jpa/plugins/org.eclipse.jpt.core/src/org/eclipse/jpt/core/context/MappingFile.java5
1 files changed, 2 insertions, 3 deletions
diff --git a/jpa/plugins/org.eclipse.jpt.core/src/org/eclipse/jpt/core/context/MappingFile.java b/jpa/plugins/org.eclipse.jpt.core/src/org/eclipse/jpt/core/context/MappingFile.java
index caedac50ab..a48813c7ba 100644
--- a/jpa/plugins/org.eclipse.jpt.core/src/org/eclipse/jpt/core/context/MappingFile.java
+++ b/jpa/plugins/org.eclipse.jpt.core/src/org/eclipse/jpt/core/context/MappingFile.java
@@ -11,7 +11,6 @@
package org.eclipse.jpt.core.context;
import org.eclipse.jpt.core.JpaStructureNode;
-import org.eclipse.jpt.core.context.orm.OrmPersistentType;
import org.eclipse.jpt.core.resource.common.JpaXmlResource;
/**
@@ -34,10 +33,10 @@ public interface MappingFile extends XmlContextNode, JpaStructureNode
MappingFileRoot getRoot();
/**
* Return the OrmPersistentType listed in this mapping file
* with the given fullyQualifiedTypeName. Return null if none exists.
*/
- OrmPersistentType getPersistentType(String fullyQualifiedTypeName);
+ PersistentType getPersistentType(String fullyQualifiedTypeName);
// **************** updating **********************************************

Back to the top
@@ -34,10 +33,10 @@ public interface MappingFile extends XmlContextNode, JpaStructureNode
MappingFileRoot getRoot();
/**
- * Return the OrmPersistentType listed in this mapping file
+ * Return the PersistentType listed in this mapping file
* with the given fullyQualifiedTypeName. Return null if none exists.
*/